==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/ro.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nu toate calendarele sunt salvate in cache",
"Everything seems to be completely cached" => "Totul pare a fi salvat în  cache",
"No calendars found." => "Nici un calendar găsit.",
"No events found." => "Nici un eveniment găsit.",
"Wrong calendar" => "Calendar greșit",
"The file contained either no events or all events are already saved in your calendar." => "Fișierul nu conținea nici nu eveniment sau toate evenimentele sunt deja salvate în calendar.",
"events has been saved in the new calendar" => "evenimentele au fost salvate în noul calendar",
"Import failed" => "importul a eșuat",
"events has been saved in your calendar" => "evenimentul a fost salvat în calendar",
"New Timezone:" => "Fus orar nou:",
"Timezone changed" => "Fus orar schimbat",
"Invalid request" => "Cerere eronată",
"Calendar" => "Calendar",
"Deletion failed" => "Ștergerea a eșuat",
"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
"user" => "utilizator",
"group" => "grup",
"Editable" => "Editabil",
"Shareable" => "Partajabil",
"Deletable" => "Se poate șterge",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "LLL z[aaaa]{'&#8212;'[LLL] z aaaa}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "Zi de naștere",
"Business" => "Afaceri",
"Call" => "Sună",
"Clients" => "Clienți",
"Deliverer" => "Curier",
"Holidays" => "Sărbători",
"Ideas" => "Idei",
"Journey" => "Călătorie",
"Jubilee" => "Aniversare",
"Meeting" => "Întâlnire",
"Other" => "Altele",
"Personal" => "Personal",
"Projects" => "Proiecte",
"Questions" => "Întrebări",
"Work" => "Servici",
"by" => "după",
"unnamed" => "fără nume",
"You do not have the permissions to update this calendar." => "Nu ai permisiunile necesare pentru a actualiza acest calendar.",
"You do not have the permissions to delete this calendar." => "Nu ai permisiunile necesare pentru a așterge acest calendar.",
"You do not have the permissions to add to this calendar." => "Nu ai permisiuni pentru a face adăugiri în acest calendar.",
"New Calendar" => "Calendar nou",
"You do not have the permissions to add events to this calendar." => "Nu ai permisiunile necesare pentru a adăuga evenimente la acest calendar.",
"You do not have the permissions to edit this event." => "Nu ai permisiunile necesare pentru a edita acest eveniment.",
"You do not have the permissions to delete this event." => "Nu ai permisiunile necesare pentru a șterge acest eveniment.",
"Does not repeat" => "Nerepetabil",
"Daily" => "Zilnic",
"Weekly" => "Săptămânal",
"Every Weekday" => "În fiecare zii a săptămânii",
"Bi-Weekly" => "La fiecare două săptămâni",
"Monthly" => "Lunar",
"Yearly" => "Anual",
"never" => "niciodată",
"by occurrences" => "după repetiție",
"by date" => "după dată",
"by monthday" => "după ziua lunii",
"by weekday" => "după ziua săptămânii",
"Monday" => "Luni",
"Tuesday" => "Marți",
"Wednesday" => "Miercuri",
"Thursday" => "Joi",
"Friday" => "Vineri",
"Saturday" => "Sâmbătă",
"Sunday" => "Duminică",
"events week of month" => "evenimentele săptămânii din luna",
"first" => "primul",
"second" => "al doilea",
"third" => "al treilea",
"fourth" => "al patrulea",
"fifth" => "al cincilea",
"last" => "ultimul",
"January" => "Ianuarie",
"February" => "Februarie",
"March" => "Martie",
"April" => "Aprilie",
"May" => "Mai",
"June" => "Iunie",
"July" => "Iulie",
"August" => "August",
"September" => "Septembrie",
"October" => "Octombrie",
"November" => "Noiembrie",
"December" => "Decembrie",
"by events date" => "după data evenimentului",
"by yearday(s)" => "după ziua(zilele) anului",
"by weeknumber(s)" => "după numărul săptămânii",
"by day and month" => "după zi și lună",
"Date" => "Data",
"Cal." => "Cal.",
"Sun." => "Dum.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mie.",
"Thu." => "Joi",
"Fri." => "Vin.",
"Sat." => "Sâm.",
"Jan." => "Ian.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai",
"Jun." => "Iun.",
"Jul." => "Iul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Noi.",
"Dec." => "Dec.",
"All day" => "Toată ziua",
"Missing fields" => "Câmpuri lipsă",
"Title" => "Titlu",
"From Date" => "Începând cu",
"From Time" => "De la",
"To Date" => "Până pe",
"To Time" => "La",
"The event ends before it starts" => "Evenimentul se termină înainte să înceapă",
"There was a database fail" => "A avut loc o eroare a bazei de date",
"Week" => "Săptămâna",
"Month" => "Luna",
"List" => "Listă",
"Today" => "Astăzi",
"Calendars" => "Calendare",
"Settings" => "Setări",
"Your calendars" => "Calendarele tale",
"CalDav Link" => "Legătură CalDav",
"Share Calendar" => "Partajați calendarul",
"Download" => "Descarcă",
"Edit" => "Modifică",
"Delete" => "Șterge",
"shared with you by" => "Partajat cu tine de",
"New calendar" => "Calendar nou",
"Edit calendar" => "Modifică calendarul",
"Displayname" => "Nume afișat",
"Active" => "Activ",
"Calendar color" => "Culoarea calendarului",
"Save" => "Salveză",
"Submit" => "Trimite",
"Cancel" => "Anulează",
"Edit an event" => "Modifică un eveniment",
"Export" => "Exportă",
"Eventinfo" => "Informații despre eveniment",
"Repeating" => "Ciclic",
"Alarm" => "Alarmă",
"Attendees" => "Participanți",
"Share" => "Partajează",
"Title of the Event" => "Numele evenimentului",
"Category" => "Categorie",
"Separate categories with commas" => "Separă categoriile prin virgule",
"Edit categories" => "Editează categorii",
"All Day Event" => "Toată ziua",
"From" => "De la",
"To" => "Către",
"Advanced options" => "Opțiuni avansate",
"Location" => "Locație",
"Location of the Event" => "Locația evenimentului",
"Description" => "Descriere",
"Description of the Event" => "Descrierea evenimentului",
"Repeat" => "Repetă",
"Advanced" => "Avansat",
"Select weekdays" => "Selectează zilele săptămânii",
"Select days" => "Selectează zilele",
"and the events day of year." => "și evenimentele de zi cu zi ale anului.",
"and the events day of month." => "și evenimentele de zi cu zi ale lunii.",
"Select months" => "Selectează lunile",
"Select weeks" => "Selectează săptămânile",
"and the events week of year." => "și evenimentele săptămânale ale anului.",
"Interval" => "Interval",
"End" => "Sfârșit",
"occurrences" => "repetiții",
"create a new calendar" => "crează un calendar nou",
"Import a calendar file" => "Importă un calendar",
"Please choose a calendar" => "Vă rugăm să alegeți un calendar",
"Name of new calendar" => "Numele noului calendar",
"Take an available name!" => "Alegeți un nume disponibil!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Un calendar cu acest nume există deja. Dacă oricum veți continua, aceste calendare vor fi fuzionate.",
"Import" => "Importă",
"Close Dialog" => "Închide",
"Create a new event" => "Crează un eveniment nou",
"Share with:" => "Partajează cu:",
"Shared with" => "Partajat cu:",
"Unshare" => "Anulează partajarea",
"Nobody" => "Nimeni",
"Shared via calendar" => "Partajat prin calendar",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTĂ: Acțiunile asupra evenimentelor partajate prin calendar vor fi aplicate la partajarea intregului calendar.",
"View an event" => "Vizualizează un eveniment",
"No categories selected" => "Nici o categorie selectată",
"of" => "din",
"at" => "la",
"General" => "Generale",
"Timezone" => "Fus orar",
"Update timezone automatically" => "Actualizați fusul orar automat",
"Time format" => "Formatul timpului",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Începe săptămâna cu",
"Cache" => "Cache",
"Clear cache for repeating events" => "Curăță cache pentru evenimente repetate",
"URLs" => "linkuri",
"Calendar CalDAV syncing addresses" => "Adrese de sincronizare calendar CalDAV",
"more info" => "mai multe informații",
"Primary address (Kontact et al)" => "Adresa primară (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Citeste numai linkuri iCalendar"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/ro.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nu toate calendarele sunt salvate in cache",
"Everything seems to be completely cached" => "Totul pare a fi salvat în  cache",
"No calendars found." => "Nici un calendar găsit.",
"No events found." => "Nici un eveniment găsit.",
"Wrong calendar" => "Calendar greșit",
"You do not have the permissions to edit this event." => "Nu ai permisiunile necesare pentru a edita acest eveniment.",
"The file contained either no events or all events are already saved in your calendar." => "Fișierul nu conținea nici nu eveniment sau toate evenimentele sunt deja salvate în calendar.",
"events has been saved in the new calendar" => "evenimentele au fost salvate în noul calendar",
"Import failed" => "importul a eșuat",
"events has been saved in your calendar" => "evenimentul a fost salvat în calendar",
"New Timezone:" => "Fus orar nou:",
"Timezone changed" => "Fus orar schimbat",
"Invalid request" => "Cerere eronată",
"Calendar" => "Calendar",
"Deletion failed" => "Ștergerea a eșuat",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "utilizator",
"group" => "grup",
"Editable" => "Editabil",
"Shareable" => "Partajabil",
"Deletable" => "Se poate șterge",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "LLL z[aaaa]{'&#8212;'[LLL] z aaaa}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Duminică",
"Monday" => "Luni",
"Tuesday" => "Marți",
"Wednesday" => "Miercuri",
"Thursday" => "Joi",
"Friday" => "Vineri",
"Saturday" => "Sâmbătă",
"Sun." => "Dum.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mie.",
"Thu." => "Joi",
"Fri." => "Vin.",
"Sat." => "Sâm.",
"January" => "Ianuarie",
"February" => "Februarie",
"March" => "Martie",
"April" => "Aprilie",
"May" => "Mai",
"June" => "Iunie",
"July" => "Iulie",
"August" => "August",
"September" => "Septembrie",
"October" => "Octombrie",
"November" => "Noiembrie",
"December" => "Decembrie",
"Jan." => "Ian.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai",
"Jun." => "Iun.",
"Jul." => "Iul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Noi.",
"Dec." => "Dec.",
"All day" => "Toată ziua",
"New Calendar" => "Calendar nou",
"Missing or invalid fields" => "Campuri necompletate sau invalide",
"Title" => "Titlu",
"From Date" => "Începând cu",
"From Time" => "De la",
"To Date" => "Până pe",
"To Time" => "La",
"The event ends before it starts" => "Evenimentul se termină înainte să înceapă",
"There was a database fail" => "A avut loc o eroare a bazei de date",
"Birthday" => "Zi de naștere",
"Business" => "Afaceri",
"Call" => "Sună",
"Clients" => "Clienți",
"Deliverer" => "Curier",
"Holidays" => "Sărbători",
"Ideas" => "Idei",
"Journey" => "Călătorie",
"Jubilee" => "Aniversare",
"Meeting" => "Întâlnire",
"Other" => "Altele",
"Personal" => "Personal",
"Projects" => "Proiecte",
"Questions" => "Întrebări",
"Work" => "Servici",
"by" => "după",
"unnamed" => "fără nume",
"You do not have the permissions to update this calendar." => "Nu ai permisiunile necesare pentru a actualiza acest calendar.",
"You do not have the permissions to delete this calendar." => "Nu ai permisiunile necesare pentru a așterge acest calendar.",
"You do not have the permissions to add to this calendar." => "Nu ai permisiuni pentru a face adăugiri în acest calendar.",
"You do not have the permissions to add events to this calendar." => "Nu ai permisiunile necesare pentru a adăuga evenimente la acest calendar.",
"You do not have the permissions to delete this event." => "Nu ai permisiunile necesare pentru a șterge acest eveniment.",
"Busy" => "Ocupat",
"Public" => "Public",
"Private" => "Privat",
"Confidential" => "Confidential",
"Does not repeat" => "Nerepetabil",
"Daily" => "Zilnic",
"Weekly" => "Săptămânal",
"Every Weekday" => "În fiecare zii a săptămânii",
"Bi-Weekly" => "La fiecare două săptămâni",
"Monthly" => "Lunar",
"Yearly" => "Anual",
"never" => "niciodată",
"by occurrences" => "după repetiție",
"by date" => "după dată",
"by monthday" => "după ziua lunii",
"by weekday" => "după ziua săptămânii",
"events week of month" => "evenimentele săptămânii din luna",
"first" => "primul",
"second" => "al doilea",
"third" => "al treilea",
"fourth" => "al patrulea",
"fifth" => "al cincilea",
"last" => "ultimul",
"by events date" => "după data evenimentului",
"by yearday(s)" => "după ziua(zilele) anului",
"by weeknumber(s)" => "după numărul săptămânii",
"by day and month" => "după zi și lună",
"Date" => "Data",
"Cal." => "Cal.",
"Week" => "Săptămâna",
"Month" => "Luna",
"List" => "Listă",
"Today" => "Astăzi",
"Settings" => "Setări",
"Your calendars" => "Calendarele tale",
"CalDav Link" => "Legătură CalDav",
"Share Calendar" => "Partajați calendarul",
"Download" => "Descarcă",
"Edit" => "Modifică",
"Delete" => "Șterge",
"New calendar" => "Calendar nou",
"Edit calendar" => "Modifică calendarul",
"Displayname" => "Nume afișat",
"Active" => "Activ",
"Calendar color" => "Culoarea calendarului",
"Save" => "Salveză",
"Submit" => "Trimite",
"Cancel" => "Anulează",
"Edit an event" => "Modifică un eveniment",
"Export" => "Exportă",
"Eventinfo" => "Informații despre eveniment",
"Repeating" => "Ciclic",
"Alarm" => "Alarmă",
"Attendees" => "Participanți",
"Share" => "Partajează",
"Title of the Event" => "Numele evenimentului",
"Category" => "Categorie",
"Separate categories with commas" => "Separă categoriile prin virgule",
"Edit categories" => "Editează categorii",
"Access Class" => "Clasa de Acces",
"All Day Event" => "Toată ziua",
"From" => "De la",
"To" => "Către",
"Advanced options" => "Opțiuni avansate",
"Location" => "Locație",
"Location of the Event" => "Locația evenimentului",
"Description" => "Descriere",
"Description of the Event" => "Descrierea evenimentului",
"Repeat" => "Repetă",
"Advanced" => "Avansat",
"Select weekdays" => "Selectează zilele săptămânii",
"Select days" => "Selectează zilele",
"and the events day of year." => "și evenimentele de zi cu zi ale anului.",
"and the events day of month." => "și evenimentele de zi cu zi ale lunii.",
"Select months" => "Selectează lunile",
"Select weeks" => "Selectează săptămânile",
"and the events week of year." => "și evenimentele săptămânale ale anului.",
"Interval" => "Interval",
"End" => "Sfârșit",
"occurrences" => "repetiții",
"create a new calendar" => "crează un calendar nou",
"Import a calendar file" => "Importă un calendar",
"Please choose a calendar" => "Vă rugăm să alegeți un calendar",
"Name of new calendar" => "Numele noului calendar",
"Take an available name!" => "Alegeți un nume disponibil!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Un calendar cu acest nume există deja. Dacă oricum veți continua, aceste calendare vor fi fuzionate.",
"Remove all events from the selected calendar" => "Sterge toate evenimentele selectate din calendar",
"Import" => "Importă",
"Close Dialog" => "Închide",
"Create a new event" => "Crează un eveniment nou",
"Share with:" => "Partajează cu:",
"Shared with" => "Partajat cu:",
"Unshare" => "Anulează partajarea",
"Nobody" => "Nimeni",
"Shared via calendar" => "Partajat prin calendar",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTĂ: Acțiunile asupra evenimentelor partajate prin calendar vor fi aplicate la partajarea intregului calendar.",
"View an event" => "Vizualizează un eveniment",
"No categories selected" => "Nici o categorie selectată",
"of" => "din",
"at" => "la",
"General" => "Generale",
"Timezone" => "Fus orar",
"Update timezone automatically" => "Actualizați fusul orar automat",
"Time format" => "Formatul timpului",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Începe săptămâna cu",
"Cache" => "Cache",
"Clear cache for repeating events" => "Curăță cache pentru evenimente repetate",
"URLs" => "linkuri",
"Calendar CalDAV syncing addresses" => "Adrese de sincronizare calendar CalDAV",
"more info" => "mai multe informații",
"Primary address (Kontact et al)" => "Adresa primară (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Citeste numai linkuri iCalendar"
);
